@@ -10,7 +10,7 @@
 
 module RbConfig
   RUBY_VERSION.start_with?("2.4.") or
-    raise "ruby lib version (2.4.1) doesn't match executable version (#{RUBY_VERSION})"
+    raise "ruby lib version (2.4.2) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/2.4/arm-openbsd")
@@ -21,9 +21,9 @@ module RbConfig
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "2"
   CONFIG["MINOR"] = "4"
-  CONFIG["TEENY"] = "1"
-  CONFIG["PATCHLEVEL"] = "111"
-  CONFIG["INSTALL"] = '/usr/obj/ports/ruby-2.4.1-no_ri_docs-bootstrap/bin/install -c '
+  CONFIG["TEENY"] = "2"
+  CONFIG["PATCHLEVEL"] = "198"
+  CONFIG["INSTALL"] = '/usr/obj/ports/ruby-2.4.2-no_ri_docs-bootstrap/bin/install -c '
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)24"
@@ -82,19 +82,19 @@ module RbConfig
   CONFIG["ENABLE_SHARED"] = "yes"
   CONFIG["DLDLIBS"] = " -lc"
   CONFIG["SOLIBS"] = "$(LIBS)"
-  CONFIG["LIBRUBYARG_SHARED"] = "-L$(libdir) -l$(RUBY_SO_NAME)"
-  CONFIG["LIBRUBYARG_STATIC"] = "-L$(libdir) -l$(RUBY_SO_NAME)-static"
+  CONFIG["LIBRUBYARG_SHARED"] = "-Wl,-rpath,$(libdir) -L$(libdir) -l$(RUBY_SO_NAME)"
+  CONFIG["LIBRUBYARG_STATIC"] = "-Wl,-rpath,$(libdir) -L$(libdir) -l$(RUBY_SO_NAME)-static"
   CONFIG["LIBRUBYARG"] = "$(LIBRUBYARG_SHARED)"
   CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
   CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_SO_NAME).so"
-  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).so.1.0"
+  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_SO_NAME).so.2.0"
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_SO_NAME)-static.a"
   CONFIG["RUBYW_INSTALL_NAME"] = ""
   CONFIG["rubyw_install_name"] = ""
   CONFIG["EXTDLDFLAGS"] = ""
   CONFIG["EXTLDFLAGS"] = ""
   CONFIG["strict_warnflags"] = "-std=gnu99"
-  CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wunused-variable -Wimplicit-int -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wimplicit-function-declaration -Wdeprecated-declarations"
+  CONFIG["warnflags"] = "-Wall -Wextra -Wno-unused-parameter -Wno-parentheses -Wno-long-long -Wno-missing-field-initializers -Wno-tautological-compare -Wno-parentheses-equality -Wno-constant-logical-operand -Wno-self-assign -Wunused-variable -Wimplicit-int -Wpointer-arith -Wwrite-strings -Wdeclaration-after-statement -Wimplicit-function-declaration -Wdeprecated-declarations -Wno-packed-bitfield-compat"
   CONFIG["debugflags"] = "-ggdb3"
   CONFIG["optflags"] = "-O3 -fno-fast-math"
   CONFIG["NULLCMD"] = ":"
@@ -115,8 +115,8 @@ module RbConfig
   CONFIG["TRY_LINK"] = ""
   CONFIG["PRELOADENV"] = "LD_PRELOAD"
   CONFIG["LIBPATHENV"] = "LD_LIBRARY_PATH"
-  CONFIG["RPATHFLAG"] = ""
-  CONFIG["LIBPATHFLAG"] = " -L%s"
+  CONFIG["RPATHFLAG"] = " -Wl,-rpath,%1$-s"
+  CONFIG["LIBPATHFLAG"] = " -L%1$-s"
   CONFIG["LINK_SO"] = ""
   CONFIG["ASMEXT"] = "S"
   CONFIG["LIBEXT"] = "a"
@@ -144,9 +144,9 @@ module RbConfig
   CONFIG["DOT"] = ""
   CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["MKDIR_P"] = "mkdir -p"
-  CONFIG["INSTALL_DATA"] = "/usr/obj/ports/ruby-2.4.1-no_ri_docs-bootstrap/bin/install -c  -m 644"
-  CONFIG["INSTALL_SCRIPT"] = "/usr/obj/ports/ruby-2.4.1-no_ri_docs-bootstrap/bin/install -c  -m 755"
-  CONFIG["INSTALL_PROGRAM"] = "/usr/obj/ports/ruby-2.4.1-no_ri_docs-bootstrap/bin/install -c -s  -m 755"
+  CONFIG["INSTALL_DATA"] = "/usr/obj/ports/ruby-2.4.2-no_ri_docs-bootstrap/bin/install -c  -m 644"
+  CONFIG["INSTALL_SCRIPT"] = "/usr/obj/ports/ruby-2.4.2-no_ri_docs-bootstrap/bin/install -c  -m 755"
+  CONFIG["INSTALL_PROGRAM"] = "/usr/obj/ports/ruby-2.4.2-no_ri_docs-bootstrap/bin/install -c -s  -m 755"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["NM"] = "nm"
@@ -183,22 +183,22 @@ module RbConfig
   CONFIG["NACL_SDK_VARIANT"] = ""
   CONFIG["NACL_SDK_ROOT"] = ""
   CONFIG["NACL_TOOLCHAIN"] = ""
-  CONFIG["target_os"] = "openbsd6.1"
+  CONFIG["target_os"] = "openbsd6.2"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "arm"
-  CONFIG["target"] = "arm-unknown-openbsd6.1"
-  CONFIG["host_os"] = "openbsd6.1"
+  CONFIG["target"] = "arm-unknown-openbsd6.2"
+  CONFIG["host_os"] = "openbsd6.2"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "arm"
-  CONFIG["host"] = "arm-unknown-openbsd6.1"
+  CONFIG["host"] = "arm-unknown-openbsd6.2"
   CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
-  CONFIG["build_os"] = "openbsd6.1"
+  CONFIG["build_os"] = "openbsd6.2"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "arm"
-  CONFIG["build"] = "arm-unknown-openbsd6.1"
-  CONFIG["RUBY_PROGRAM_VERSION"] = "2.4.1"
+  CONFIG["build"] = "arm-unknown-openbsd6.2"
+  CONFIG["RUBY_PROGRAM_VERSION"] = "2.4.2"
   CONFIG["cxxflags"] = "$(optflags) $(debugflags) $(warnflags)"
   CONFIG["cppflags"] = ""
   CONFIG["cflags"] = "$(optflags) $(debugflags) $(warnflags)"
